@@ -31,7 +31,7 @@ video_youtube::video_youtube()
     this->_supportsDescription = true;
     this->_supportsThumbnail = true;
     this->_supportsSearch = true;
-    this->_icon = 0;
+    this->_icon = nullptr;
     this->_urlRegExp << QRegExp("http[s]?://\\w*\\.youtube\\.com/watch.*v\\=.*", Qt::CaseInsensitive);
     this->_urlRegExp << QRegExp("http[s]?://\\w*\\.youtube\\.com/view_play_list\\?p\\=.*&v\\=.*", Qt::CaseInsensitive);
     this->_urlRegExp << QRegExp("http[s]?://youtu.be/.*", Qt::CaseInsensitive);
@@ -200,7 +200,7 @@ void video_youtube::extractJSMethod(QString name, QString js) {
         QString code = expression.cap(4);
         QString parameters = expression.cap(3).replace(QRegExp("[\\(\\)\\s]"), "");
 
-        for (qint64 i = 1; i < code.length(); i++) {
+        for (int i = 1; i < code.length(); i++) {
             QString partial = code.left(i);
             if (partial.count("{") == partial.count("}")) {
                 method.code = descriptor +  partial;
@@ -453,12 +453,46 @@ void video_youtube::parseVideo(QString html)
 
         expression = QRegExp("\"url_encoded_fmt_stream_map\": ?\"(.*)\"");
         expression.setMinimal(true);
-
         if (expression.indexIn(html)!=-1 && expression.cap(1) != "")
         {
             qualityLinks << expression.cap(1).split(",");
         }
 
+        expression = QRegExp("\\\\\"adaptiveFormats\\\\\":\\[(.*)\\]");
+        expression.setMinimal(true);
+        if (expression.indexIn(html) != -1 && expression.cap(1) != "")
+        {
+            QString input = "[" + expression.cap(1).replace(QRegExp("\\\\(?![\\\\])"), "").replace(("\\\\"), "\\") + "]";
+            QJsonParseError* parseError = new QJsonParseError();
+            QJsonArray adaptiveFormats = QJsonDocument::fromJson(input.toLatin1(), parseError).array();
+
+            if (!parseError->errorString().isEmpty()) {
+                qDebug() << "Error parsing JSON data" << parseError->errorString() << parseError->offset;
+                qDebug() << input.mid(parseError->offset > 16 ? parseError->offset - 16 : 0, 32);
+            }
+
+            for (int i = 0; i < adaptiveFormats.count(); i++)
+            {
+                QJsonObject adaptiveFormat = adaptiveFormats.at(i).toObject();
+                QStringList qualityLinkSegements;
+                QStringList intKeys(QStringList() << "itag" << "audioChannels" << "averageBitrate" << "bitrate" << "indexRange" << "initRange");
+                QStringList appendKeys(QStringList() << "cipher");
+                for (int j = 0; j < adaptiveFormat.keys().length(); j++)
+                {
+                    QString key = adaptiveFormat.keys().at(j);
+                    if (intKeys.contains(key)) {
+                        qualityLinkSegements << key + "=" + QString::number(adaptiveFormat.value(key).toInt());
+                    } else if (appendKeys.contains(key)) {
+                        qualityLinkSegements << adaptiveFormat.value(key).toString().replace("&", ",");
+                    }
+                    else {
+                        qualityLinkSegements << key + "=" + QUrl::toPercentEncoding(adaptiveFormat.value(key).toString());
+                    }
+                }
+                qualityLinks << qualityLinkSegements.join(",");
+            }
+        }
+
         if (!qualityLinks.isEmpty() || ! this->dashQualityLinks.isEmpty())
         {
 
